.. :changelog:

History
-------

1.0.0 (2016-03-24)
++++++++++++++++++

* New settings var for configure Elasticsearch connection.
* Better project structure for distribution.


1.0.0rc1 (2016-02-29)
+++++++++++++++++++++

* First release on PyPI.
